summaryrefslogtreecommitdiff
path: root/src/ladmin
diff options
context:
space:
mode:
authorultramage <ultramage@54d463be-8e91-2dee-dedb-b68131a5f0ec>2007-03-22 21:03:19 +0000
committerultramage <ultramage@54d463be-8e91-2dee-dedb-b68131a5f0ec>2007-03-22 21:03:19 +0000
commit162af4caa481eef2529ccdc1299d9578539143c9 (patch)
tree26fbac5a3aa31aa02096d567534fbed35dda8c6b /src/ladmin
parentfad0a74cd53f827e4c006b497b658baca2065a3d (diff)
downloadhercules-162af4caa481eef2529ccdc1299d9578539143c9.tar.gz
hercules-162af4caa481eef2529ccdc1299d9578539143c9.tar.bz2
hercules-162af4caa481eef2529ccdc1299d9578539143c9.tar.xz
hercules-162af4caa481eef2529ccdc1299d9578539143c9.zip
Some generic typo fixes (src and npc)
git-svn-id: https://rathena.svn.sourceforge.net/svnroot/rathena/trunk@10054 54d463be-8e91-2dee-dedb-b68131a5f0ec
Diffstat (limited to 'src/ladmin')
-rw-r--r--src/ladmin/ladmin.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/ladmin/ladmin.c b/src/ladmin/ladmin.c
index 3f75edca8..947af1900 100644
--- a/src/ladmin/ladmin.c
+++ b/src/ladmin/ladmin.c
@@ -125,7 +125,7 @@ char date_format[32] = "%Y-%m-%d %H:%M:%S";
//
// check <account_name> <password>
// Check the validity of a password for an account
// NOTE: Server will never sends back a password.
// It's the only method you have to know if a password is correct.
// The other method is to have a ('physical') access to the accounts file.
//
@@ -933,7 +933,7 @@ void display_help(char* param, int language) {
} else if (strcmp(command, "check") == 0) {
printf("check <account_name> <password>\n");
printf(" Check the validity of a password for an account.\n");
- printf(" NOTE: Server will never sends back a password.\n");
+ printf(" NOTE: Server will never send back a password.\n");
printf(" It's the only method you have to know if a password is correct.\n");
printf(" The other method is to have a ('physical') access to the accounts file.\n");
} else if (strcmp(command, "create") == 0) {
@@ -125,7 +125,7 @@ char date_format[32] = "%Y-%m-%d %H:%M:%S";
// check <account_name> <password>
// Check the validity of a password for an account
-// NOTE: Server will never sends back a password.
+// NOTE: Server will never send back a password.
// It's the only method you have to know if a password is correct.
// The other method is to have a ('physical') access to the accounts file.